==> partial_page_print-1.0.0.tar.gz: partial_page_print/js/printButton.js <==
(function (Drupal, drupalSettings, once) {
  const printElementFrameName = 'print_element_frame';
  const init = () => {
    // Create the iframe that we can use to place the element for printing.
    if (!document.getElementById(printElementFrameName)) {
      let printIframe = document.createElement('iframe');
      printIframe.setAttribute('name', printElementFrameName);
      printIframe.setAttribute('id', printElementFrameName);
      printIframe.setAttribute('src', `${window.location.origin + drupalSettings.path.baseUrl + drupalSettings.path.pathPrefix}print-document`);
      printIframe.setAttribute('style', 'display:none; position:absolute; ');
      printIframe.setAttribute('width', '1200');
      printIframe.setAttribute('height', '100');
      document.body.appendChild(printIframe);
    }
  };

  Drupal.behaviors.partialPagePrintInit = {
    attach: function (context, settings) {
      once('partialPagePrintInit', 'html', context).forEach(element => {
        init();
      });
    }
  };

  Drupal.behaviors.partialPagePrint = {
    attach: function (context, settings) {
      once('partialPagePrint', '[data-print-element-id]', context).forEach(element => {
        element.addEventListener('click', event => {
          const buttonText = event.target.innerHTML;
          const printElementId = event.target.getAttribute('data-print-element-id');
          const elementToPrint= document.getElementById(printElementId);
          if (!elementToPrint) {
            console.error('Unable to print element with id ' + printElementId + ' because it is not found in current document.');
            return;
          }

          // Update the button text.
          event.target.innerHTML = Drupal.t('Generating...');

          // Update the iframed document title to match current page title because this can be shown on the printed page in the header.
          window.frames[printElementFrameName].document.title = document.title;

          // Place the element in the iframe to print.
          window.frames[printElementFrameName].postMessage(elementToPrint.innerHTML, '*');

          // Give the browser a moment to render the element in the iframe then print.
          setTimeout(() => {
            // Print the frame
            window.frames[printElementFrameName].window.focus();
            window.frames[printElementFrameName].window.print();

            // Restore button text.
            event.target.innerHTML = buttonText;
          }, 500 );
        });
      });
    }
  };
})(Drupal, drupalSettings, once);

==> partial_page_print-1.0.1.tar.gz: partial_page_print/js/printButton.js <==
(function (Drupal, drupalSettings, once) {
  const printElementFrameName = 'print_element_frame';
  const init = () => {
    // Create the iframe that we can use to place the element for printing.
    if (!document.getElementById(printElementFrameName)) {
      let printIframe = document.createElement('iframe');
      printIframe.setAttribute('name', printElementFrameName);
      printIframe.setAttribute('id', printElementFrameName);
      printIframe.setAttribute('src', `${window.location.origin + drupalSettings.path.baseUrl + drupalSettings.path.pathPrefix}print-document`);
      printIframe.setAttribute('style', 'display:none; position:absolute; ');
      printIframe.setAttribute('width', '1200');
      printIframe.setAttribute('height', '100');
      document.body.appendChild(printIframe);
    }
  };

  Drupal.behaviors.partialPagePrintInit = {
    attach: function (context, settings) {
      once('partialPagePrintInit', 'html', context).forEach(element => {
        init();
      });
    }
  };

  Drupal.behaviors.partialPagePrint = {
    attach: function (context, settings) {
      once('partialPagePrint', '[data-print-element-id]', context).forEach(element => {
        element.addEventListener('click', event => {
          const buttonText = event.target.innerHTML;
          const printElementId = event.target.getAttribute('data-print-element-id');
          const elementToPrint= document.getElementById(printElementId);
          if (!elementToPrint) {
            console.error('Unable to print element with id ' + printElementId + ' because it is not found in current document.');
            return;
          }

          // Update the button text.
          event.target.innerHTML = Drupal.t('Generating...');

          // Update the iframed document title to match current page title because this can be shown on the printed page in the header.
          window.frames[printElementFrameName].document.title = document.title;

          // Place the element in the iframe to print.
          window.frames[printElementFrameName].postMessage({printableElement: elementToPrint.innerHTML}, '*');

          // Give the browser a moment to render the element in the iframe then print.
          setTimeout(() => {
            // Print the frame
            window.frames[printElementFrameName].window.focus();
            window.frames[printElementFrameName].window.print();

            // Restore button text.
            event.target.innerHTML = buttonText;
          }, 1000 );
        });
      });
    }
  };
})(Drupal, drupalSettings, once);
